# R_Test_Script.R:
#
# This is  a test R script demonstrating Batch R invocation and parameter passing to R!
# The script simple reads the input parameters to the R script and prints them in standard-output stream.
# The printing of the arguments step needs to be replaced by the real and necessary R processing that
# needs to be done on the input (which may be file-names, directories, strings, or numbers ...
# INCF/IBRO 2017 Summer School (http://wiki.socr.umich.edu/index.php/SOCR_News_IBRO_INSF_Malaysia_2017)
# Ivo Dinov, LGPL license
#
# Example Usage:
#  /usr/local/R/bin/R --slave --no-save --no-restore --no-environ --silent --args inputCaseStudyURL.img outputReport.pdf < QoL_CaseStudy_ML_R_BatchExecution_PL_Example.R
# 
# This usage will generate the following output:
# Reading arguments
# /usr/local/R-2.4.1-2_64bit/lib64/R/bin/exec/R.exec
# --slave
# --no-save
# --no-restore
# --no-environ
# --silent
# --args
# inputfile=inputCaseStudyURL.img
# outputfile=outputReport.pdf
# ...
# ... (results as in the DSAPA EBook: http://www.socr.umich.edu/people/dinov/2017/Spring/DSPA_HS650/notes/22_DeepLearning.html#54_country_qol_ranking_data)

# Begin the real R script -- printing of the arguments (needs to be replaced by real R processing steps!)
#
cat("Reading arguments ... \n", sep = "");

# Read all arguments in the R program ...
cmd_args = commandArgs(); 

# Print all arguments demonstrating the inputs are readily available within R for processing ...
for (arg in cmd_args) {
  cat(" ", arg, "\n", sep="")
}

## args is a list of character vectors
## Check to see if arguments are provided, otherwise exit, and 
## cycle through each element of the argument list

if(length(cmd_args) != 2 + 7){
  print("You must provide 2 arguments: inputCaseStudyURL.img outputReport.pdf. Exiting ...")
  q()
} 
# else{
# for(i in 1:length(cmd_args)){
#    eval(parse(text=cmd_args[[i]]))
#  }
# }

inputFile <- cmd_args[[8]]; outputFile <- cmd_args[[9]]
print(inputFile); print(outputFile)

pdf(file=outputFile)

# Use the sink() function to redirect all the output to an external file
# sink(outputFile, append=FALSE, split=FALSE)

# Data: Country QoL Ranking Data:
# http://wiki.stat.ucla.edu/socr/index.php/SOCR_Data_2008_World_CountriesRankings
# A case-study of country quality of life (QoL). We will try to build a network model to predict the overall QoL.
# Note that for other data from teh Case-Studies folder ()
# We may need a simpler data import like:
# als <- read.csv("https://umich.instructure.com/files/1789624/download?download_frd=1") # e.g., for the ALS dataset

als <- read.csv("/ifs/loni/ccb/data/2017/ALS.csv")

als <- scale(als[ , -c(1,7)])
set.seed(1234)
train.ind = sample(1:nrow(als),0.7*nrow(als))
train.x = data.matrix(als[train.ind,-c(1,7)])
train.y = als[train.ind,7]
test.x = data.matrix(scale(als[-train.ind,-c(1,7)]))
test.y = als[-train.ind,7]

train_data <- as.data.frame(cbind(train.x, train.y))
# Build the neural net model
als_model<-lm(train.y ~ trunk_max+ onset_delta_mean+ ALSFRS_Total_range, data=train_data)
plot(als_model)

# Predict the labels for the testing data
preds = predict(als_model, as.data.frame(test.x)); preds

plot(preds, test.y)

# return output to the terminal
# sink()
dev.off()

# close the R script appropriately: exit(0), or q()
on.exit(0); q()
